aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-rtp.h
diff options
context:
space:
mode:
authorAnders Broman <anders.broman@ericsson.com>2005-03-27 21:14:48 +0000
committerAnders Broman <anders.broman@ericsson.com>2005-03-27 21:14:48 +0000
commit8e083f4c2e9127f9a36230abbfb8243e80b3fc0b (patch)
tree4971dd52f8df01c044a8e75d3622e0693df44a1a /epan/dissectors/packet-rtp.h
parentb5835914555a0b0f1ff99e3eb883b64ac4e1b0d5 (diff)
Previous commit failed doing them one by one.
From Alejandro Vaquero : Find attached a patch for SDP sessions to: - Dissect Dynamic payload types in RTP packets - Add the dynamic payload type description in RTP packets - Add RTP dynamic payload types description in the Voip Calls Graph, in the RTP and SDP. svn path=/trunk/; revision=13941
Diffstat (limited to 'epan/dissectors/packet-rtp.h')
-rw-r--r--epan/dissectors/packet-rtp.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/epan/dissectors/packet-rtp.h b/epan/dissectors/packet-rtp.h
index bbe9d8017b..84dedb0351 100644
--- a/epan/dissectors/packet-rtp.h
+++ b/epan/dissectors/packet-rtp.h
@@ -58,7 +58,7 @@ struct _rtp_conversation_info
{
gchar method[MAX_RTP_SETUP_METHOD_SIZE + 1];
guint32 frame_number;
- guint32 rtp_event_pt; /* this is payload type for dynamic RTP events (RFC2833) */
+ GHashTable *rtp_dyn_payload; /* a hash table with the dynamic RTP payload */
};
/* Add an RTP conversation with the given details */
@@ -67,4 +67,8 @@ void rtp_add_address(packet_info *pinfo,
int other_port,
gchar *setup_method,
guint32 setup_frame_number,
- int rtp_event_pt);
+ GHashTable *rtp_dyn_payload);
+
+/* Free and destroy the dyn_payload hash table */
+void rtp_free_hash_dyn_payload(GHashTable *rtp_dyn_payload);
+